//
// C++ Interface:
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//

#ifndef KMFIPV4ADDRESSWIDGET_H
#define KMFIPV4ADDRESSWIDGET_H

#include "kmyfirewallipv4adddresswidget.h"

// QT include
#include <tqguardedptr.h>

namespace KMF {
class IPAddress;

class KMFIPv4AddressWidget : public KMyFirewallIPv4AdddressWidget {
		TQ_OBJECT
  

	public:
		KMFIPv4AddressWidget ( TQWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
		~KMFIPv4AddressWidget();
		void loadIPAddress( int, int, int, int );
		
		/*$PUBLIC_FUNCTIONS$*/

	public slots:
		/*$PUBLIC_SLOTS$*/

	protected:
		/*$PROTECTED_FUNCTIONS$*/

	protected slots:
		/*$PROTECTED_SLOTS$*/
		void slotAddressChanged( const TQString& );
	
	private:
// 		IPAddress *m_address;
	
	signals:
		void sigAddressChanged( int, int, int, int );
};
}
#endif

